@@ -16,15 +16,14 @@
 #
 import ConfigParser
 import keyring
+from novaclient import client as novaclient
 import os
+import rackspace_auth_plugin
 import re
 import subprocess
 import sys
 
 
-__version__ = '0.7.4'
-
-
 class SuperNova:
 
     def __init__(self):
@@ -72,7 +71,7 @@ class SuperNova:
         configuration parameter pair.
         """
         try:
-            return keyring.get_password('supernova', username)
+            return keyring.get_password('supernova', username).encode('ascii')
         except:
             return False
 
@@ -107,11 +106,11 @@ class SuperNova:
 
             # Get values from the keyring if we find a USE_KEYRING constant
             if value.startswith("USE_KEYRING"):
+                rex = "USE_KEYRING\[([\x27\x22])(.*)\\1\]"
                 if value == "USE_KEYRING":
                     username = "%s:%s" % (self.nova_env, param)
                 else:
-                    global_identifier = re.match(
-                        "USE_KEYRING\['(.*)'\]",value).group(1)
+                    global_identifier = re.match(rex, value).group(2)
                     username = "%s:%s" % ('global', global_identifier)
                 credential = self.password_get(username)
             else:
@@ -159,4 +158,39 @@ class SuperNova:
         )
 
         # Don't exit until we're sure the subprocess has exited
-        p.wait()
+        return p.wait()
+
+    def get_novaclient(self, env):
+        """
+        Returns python novaclient object authenticated with supernova config.
+        """
+        self.nova_env = env
+        assert self.is_valid_environment(), "Env %s not found in config." % env
+        return novaclient.Client(**self.prep_python_creds())
+
+    def prep_python_creds(self):
+        """
+        Prepare credentials for python Client instantiation.
+        """
+        creds = {rm_prefix(k[0].lower()): k[1] for k in self.prep_nova_creds()}
+        if creds.get('auth_system') == 'rackspace':
+            creds['auth_plugin'] = rackspace_auth_plugin
+        if creds.get('url'):
+            creds['auth_url'] = creds.pop('url')
+        if creds.get('tenant_name'):
+            creds['project_id'] = creds.pop('tenant_name')
+        return creds
+
+
+def rm_prefix(name):
+    """
+    Removes nova_ os_ novaclient_ prefix from string.
+    """
+    if name.startswith('nova_'):
+        return name[5:]
+    elif name.startswith('novaclient_'):
+        return name[11:]
+    elif name.startswith('os_'):
+        return name[3:]
+    else:
+        return name
